@@ -1,7 +1,7 @@
 """Python 3 API wrapper for FireServiceRota and BrandweerRooster."""
 from typing import Optional
-#import json
-#import time
+import json
+import time
 from collections import deque
 import oauthlib.oauth2
 import websocket
@@ -218,7 +218,6 @@ class FireServiceRota(object):
         return None
 
 
-
 class FireServiceRotaIncidents(Thread, websocket.WebSocketApp):
     def __init__(self, url,
                  on_incident=None,
@@ -281,8 +280,7 @@ class FireServiceRotaIncidents(Thread, websocket.WebSocketApp):
             logging.exception(e)
 
     def run_forever(self, sockopt=None, sslopt=None, ping_interval=0, ping_timeout=None):
-        if logging.getLogger().level == logging.DEBUG:
-            websocket.enableTrace(True)
+        #    websocket.enableTrace(True)
         websocket.WebSocketApp.run_forever(self, sockopt=sockopt, sslopt=sslopt, ping_interval=ping_interval,
                                            ping_timeout=ping_timeout)
 
